#
# spec file for package perl-strictures
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-strictures
Version:        2.000003
Release:        1.1
%define cpan_name strictures
Summary:        Turn On Strict and Make Most Warnings Fatal
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/strictures/
Source0:        http://www.cpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(bareword::filehandles)
BuildRequires:  perl(indirect)
BuildRequires:  perl(multidimensional)
Requires:       perl(bareword::filehandles)
Requires:       perl(indirect)
Requires:       perl(multidimensional)
%{perl_requires}

%description
I've been writing the equivalent of this module at the top of my code for
about a year now. I figured it was time to make it shorter.

Things like the importer in 'use Moose' don't help me because they turn
warnings on but don't make them fatal -- which from my point of view is
useless because I want an exception to tell me my code isn't
warnings-clean.

Any time I see a warning from my code, that indicates a mistake.

Any time my code encounters a mistake, I want a crash -- not spew to STDERR
and then unknown (and probably undesired) subsequent behaviour.

I also want to ensure that obvious coding mistakes, like indirect object
syntax (and not so obvious mistakes that cause things to accidentally
compile as such) get caught, but not at the cost of an XS dependency and
not at the cost of blowing things up on another machine.

Therefore, strictures turns on additional checking, but only when it thinks
it's running in a test file in a VCS checkout -- although if this causes
undesired behaviour this can be overridden by setting the
'PERL_STRICTURES_EXTRA' environment variable.

If additional useful author side checks come to mind, I'll add them to the
'PERL_STRICTURES_EXTRA' code path only -- this will result in a minor
version increase (e.g. 1.000000 to 1.001000 (1.1.0) or similar). Any fixes
only to the mechanism of this code will result in a sub-version increase
(e.g. 1.000000 to 1.000001 (1.0.1)).

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Thu May  5 2016 coolo@suse.com
- updated to 2.000003
  see /usr/share/doc/packages/perl-strictures/Changes
  2.000003 - 2016-04-19
  - update bundled ExtUtils::HasCompiler to 0.013 to fix potential false
    negative (RT#113637)
  - list optional XS dependencies as suggests rather than recommends (RT#107393)
* Mon Nov  9 2015 coolo@suse.com
- updated to 2.000002
  see /usr/share/doc/packages/perl-strictures/Changes
  2.000002 - 2015-11-04
  - use ExtUtils::HasCompiler to detect compiler rather than ExtUtils::CBuilder
  - more comprehensive testing
* Mon Jun 29 2015 coolo@suse.com
- updated to 2.000001
  see /usr/share/doc/packages/perl-strictures/Changes
  2.000001 - 2015-06-28
  - update for perl 5.22 warning categories
  - avoid using goto &UNIVERSAL::VERSION on perl 5.8, since it segfaults some
    builds
  - also detect development directories based on .bzr directory
  - various test cleanups
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.000000
  see /usr/share/doc/packages/perl-strictures/Changes
  2.000000 - 2015-02-26
  * Incompatible Changes
  - strictures 2 fatalizes only a subset of warnings.  Some warning
    categories are not safe to catch, or just inappropriate to have fatal.
    Existing code looking like 'use strictures 1;' will continue to get the
    old behavior of fatalizing all errors.  The new behavior will take effect
    when no version or version 2 is specified.
* Sat Feb  7 2015 coolo@suse.com
- updated to 1.005006
  - fix extra checks triggering on paths starting with t, xt, lib, or blib,
    rather than only triggering on those directories.
  - avoid stat checks for VCS directories until we are in an appropriately
    named file
  - various cleanups in test files
* Tue Sep 16 2014 coolo@suse.com
- updated to 1.005005
  - include minimum perl version in metadata
  - make sure meta files list extra modules as recommendations, not requirements
* Mon Feb 24 2014 coolo@suse.com
- updated to 1.005003
  - added support for PUREPERL_ONLY (rt#91407)
  - fixed using strictures->VERSION to query the version (rt#92965)
  - extra prereqs will be listed as hard prerequisites if a compiler is
    available
* Mon Nov 25 2013 coolo@suse.com
- updated to 1.005001
  - fix skip on old perl on test script
  - detect mercurial when checking for development trees
  - avoid using constant.pm to save a bit of memory on older perls
  - update to v2 metadata
  - fix crash in 1.004003 due to qw() list being readonly
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.004004
  - fix 5.16 crash due to qw() list being readonly
  - check only once for presence of extra testing prereqs
  - explicitly specify no dynamic_config in META
  - add better rationale for the extra testing heuristic
  - test-specific strictures now enabled during 'dzil test'
  - switch to testing calling file to avoid firing on dependencies
* Wed May 23 2012 coolo@suse.com
- updated to 1.003001
  - fix test to handle defatalization
  - try and run for any checkout t/ now we don't blow up the process
  - defatalize lack of extra testing modules
  - disable extra tests on perls <= 5.008003, things do not work there as
    expected
* Thu Mar  3 2011 pascal.bleser@opensuse.org
- initial version (1.002002)
